@@ -12,6 +12,10 @@ class BaseState(metaclass=ABCMeta):
     Create custom states by inheriting from it.
     """
 
+    @property
+    def state_name(self):
+        return self.__class__.__name__
+
     def _handlers(self) -> List[Tuple[str, Callable]]:
         """Получить методы которые декорированы декораторами event и events."""
 
