@@ -111,3 +111,10 @@ class TestStateMethods(unittest.TestCase):
 
         state = State()
         state._traverse_handlers('update', 'state_data')
+
+    def test_state_name(self):
+        class MyCustomState(BaseState):
+            pass
+
+        state = MyCustomState()
+        self.assertEqual(state.state_name, 'MyCustomState')
